@@ -9,7 +9,7 @@
 //! }
 //! ```
 //!
-//! Your type *must* have a field called `geometry` and it must be `deserialized_with` [`deserialize_geometry`](crate::de::deserialize_geometry):
+//! Your type *must* have a field called `geometry` and it must be `deserialize_with` [`deserialize_geometry`](crate::de::deserialize_geometry):
 //!  ```rust, ignore
 //! #[derive(serde::Deserialize)]
 //! struct MyStruct {
@@ -30,7 +30,7 @@
 //!
 //! #[derive(Deserialize)]
 //! struct MyStruct {
-//!     // Deserialize from geojson, rather than expecting the type's default serialization
+//!     // Deserialize from GeoJSON, rather than expecting the type's default serialization
 //!     #[serde(deserialize_with = "deserialize_geometry")]
 //!     geometry: geo_types::Point<f64>,
 //!     name: String,
@@ -76,7 +76,7 @@
 //! ```ignore
 //! #[derive(serde::Serialize, serde::Deserialize)]
 //! struct MyStruct {
-//!     // Serialize as geojson, rather than using the type's default serialization
+//!     // Serialize as GeoJSON, rather than using the type's default serialization
 //!     #[serde(serialize_with = "serialize_geometry", deserialize_with = "deserialize_geometry")]
 //!     geometry: geo_types::Point<f64>,
 //!     ...
@@ -234,7 +234,64 @@ where
     let geojson_geometry = crate::Geometry::deserialize(deserializer)?;
     geojson_geometry
         .try_into()
-        .map_err(|err| Error::custom(format!("unable to convert from geojson Geometry: {}", err)))
+        .map_err(deserialize_error_msg::<D>)
+}
+
+/// [`serde::deserialize_with`](https://serde.rs/field-attrs.html#deserialize_with) helper to deserialize an optional GeoJSON Geometry into another type,
+/// like an optional [`geo_types`] Geometry.
+///
+/// # Examples
+#[cfg_attr(feature = "geo-types", doc = "```")]
+#[cfg_attr(not(feature = "geo-types"), doc = "```ignore")]
+/// use geojson::de::deserialize_optional_geometry;
+/// use serde::Deserialize;
+/// use serde_json::{json, from_value};
+///
+/// #[derive(Deserialize)]
+/// struct MyStruct {
+///     #[serde(rename = "count")]
+///     _count: usize,
+///     #[serde(default, deserialize_with = "deserialize_optional_geometry")]
+///     geometry: Option<geo_types::Point<f64>>,
+/// }
+///
+/// let json = json! {{
+///     "count": 0,
+///     "geometry": {
+///         "type": "Point",
+///         "coordinates": [125.6, 10.1]
+///     },
+/// }};
+/// let feature: MyStruct = from_value(json).unwrap();
+/// assert!(feature.geometry.is_some());
+///
+/// let json = json! {{
+///     "count": 1,
+/// }};
+/// let feature: MyStruct = from_value(json).unwrap();
+/// assert!(feature.geometry.is_none())
+/// ```
+pub fn deserialize_optional_geometry<'de, D, G>(
+    deserializer: D,
+) -> std::result::Result<Option<G>, D::Error>
+where
+    D: Deserializer<'de>,
+    G: TryFrom<crate::Geometry>,
+    G::Error: std::fmt::Display,
+{
+    Option::<crate::Geometry>::deserialize(deserializer)?
+        .map(TryInto::try_into)
+        .transpose()
+        .map_err(deserialize_error_msg::<D>)
+}
+
+fn deserialize_error_msg<'de, D: Deserializer<'de>>(
+    error: impl std::fmt::Display,
+) -> <D as serde::Deserializer<'de>>::Error {
+    Error::custom(format!(
+        "unable to convert from geojson Geometry: {}",
+        error
+    ))
 }
 
 /// Deserialize a GeoJSON FeatureCollection into [`Feature`] structs.
@@ -291,6 +348,57 @@ where
     Ok(deserializer.deserialize_map(visitor)?)
 }
 
+/// Interpret a [`Feature`] as an instance of type `T`.
+///
+/// This is analogous to [`serde_json::from_value`](https://docs.rs/serde_json/latest/serde_json/fn.from_value.html)
+///
+/// `T`'s `geometry` field will be deserialized from `feature.geometry`.
+/// All other fields will be deserialized from `feature.properties`.
+///
+/// # Examples
+#[cfg_attr(feature = "geo-types", doc = "```")]
+#[cfg_attr(not(feature = "geo-types"), doc = "```ignore")]
+/// use serde::Deserialize;
+/// use geojson::Feature;
+/// use geojson::de::{from_feature, deserialize_geometry, deserialize_single_feature};
+/// use std::str::FromStr;
+///
+/// #[derive(Deserialize)]
+/// struct MyStruct {
+///     // Deserialize `geometry` as GeoJSON, rather than using the type's default deserialization
+///     #[serde(deserialize_with = "deserialize_geometry")]
+///     geometry: geo_types::Point,
+///     name: String,
+/// }
+///
+/// let geojson_str = r#"{
+///     "type": "Feature",
+///     "geometry": { "type": "Point", "coordinates": [1.0, 2.0] },
+///     "properties": {
+///         "name": "My Name"
+///     }
+/// }"#;
+/// let feature  = Feature::from_str(geojson_str).unwrap();
+///
+/// let my_struct: MyStruct = from_feature(feature).unwrap();
+///
+/// assert_eq!("My Name", my_struct.name);
+/// assert_eq!(geo_types::Point::new(1.0, 2.0), my_struct.geometry);
+/// ```
+///
+/// # Errors
+///
+/// Deserialization can fail if `T`'s implementation of `Deserialize` decides to fail.
+pub fn from_feature<'de, T>(feature: Feature) -> Result<T>
+where
+    T: Deserialize<'de>,
+{
+    let feature_value: JsonValue = serde_json::to_value(feature)?;
+    let deserializer = feature_value.into_deserializer();
+    let visitor = FeatureVisitor::new();
+    Ok(deserializer.deserialize_map(visitor)?)
+}
+
 struct FeatureVisitor<D> {
     _marker: PhantomData<D>,
 }
@@ -367,7 +475,7 @@ where
 pub(crate) mod tests {
     use super::*;
 
-    use crate::JsonValue;
+    use crate::{JsonObject, JsonValue};
 
     use serde_json::json;
 
@@ -414,7 +522,7 @@ pub(crate) mod tests {
 
         assert_eq!(records.len(), 2);
         let first_age = {
-            let props = records.get(0).unwrap().properties.as_ref().unwrap();
+            let props = records.first().unwrap().properties.as_ref().unwrap();
             props.get("age").unwrap().as_i64().unwrap()
         };
         assert_eq!(first_age, 123);
@@ -527,6 +635,68 @@ pub(crate) mod tests {
             let expected_err_text = r#"Error while deserializing JSON: unable to convert from geojson Geometry: Expected type: `LineString`, but found `Point`"#;
             assert_eq!(err.to_string(), expected_err_text);
         }
+
+        #[test]
+        fn deserializes_optional_point() {
+            #[derive(serde::Deserialize)]
+            struct MyStruct {
+                #[serde(rename = "count")]
+                _count: usize,
+                #[serde(default, deserialize_with = "deserialize_optional_geometry")]
+                geometry: Option<geo_types::Point<f64>>,
+            }
+
+            let json = json! {{
+                "count": 0,
+                "geometry": {
+                    "type": "Point",
+                    "coordinates": [125.6, 10.1]
+                },
+            }};
+            let feature: MyStruct = serde_json::from_value(json).unwrap();
+            assert!(feature.geometry.is_some());
+
+            let json = json! {{
+                "count": 1,
+            }};
+            let feature: MyStruct = serde_json::from_value(json).unwrap();
+            assert!(feature.geometry.is_none())
+        }
+
+        #[test]
+        fn test_from_feature() {
+            #[derive(Debug, PartialEq, Deserialize)]
+            struct MyStruct {
+                #[serde(deserialize_with = "deserialize_geometry")]
+                geometry: geo_types::Point<f64>,
+                name: String,
+                age: u64,
+            }
+
+            let feature = Feature {
+                bbox: None,
+                geometry: Some(crate::Geometry::new(crate::Value::Point(vec![125.6, 10.1]))),
+                id: None,
+                properties: Some(
+                    json!({
+                        "name": "Dinagat Islands",
+                        "age": 123,
+                    })
+                    .as_object()
+                    .unwrap()
+                    .clone(),
+                ),
+                foreign_members: None,
+            };
+
+            let actual: MyStruct = from_feature(feature).unwrap();
+            let expected = MyStruct {
+                geometry: geo_types::Point::new(125.6, 10.1),
+                name: "Dinagat Islands".to_string(),
+                age: 123,
+            };
+            assert_eq!(actual, expected);
+        }
     }
 
     #[cfg(feature = "geo-types")]
@@ -588,4 +758,77 @@ pub(crate) mod tests {
 
         assert_eq!(actual_output_json, expected_output_json);
     }
+
+    #[cfg(feature = "geo-types")]
+    #[test]
+    fn all_props() {
+        use crate::ser::serialize_geometry;
+        use serde::{Deserialize, Serialize};
+
+        #[derive(Serialize, Deserialize)]
+        struct MyStruct {
+            #[serde(
+                serialize_with = "serialize_geometry",
+                deserialize_with = "deserialize_geometry"
+            )]
+            geometry: geo_types::Point<f64>,
+
+            #[serde(flatten)]
+            properties: JsonObject,
+        }
+
+        let feature_collection_string = feature_collection().to_string();
+        let bytes_reader = feature_collection_string.as_bytes();
+
+        let mut elements = deserialize_feature_collection_to_vec::<MyStruct>(bytes_reader).unwrap();
+        for element in &mut elements {
+            // dbg!(&element.properties);
+            // => [src/de.rs:615] &element.properties = {
+            //    "age": Number(123),
+            //    "name": String("Dinagat Islands"),
+            // }
+            let mut age = element
+                .properties
+                .get("age")
+                .expect("key to exist")
+                .as_u64()
+                .expect("numeric");
+            age += 1;
+            *element.properties.get_mut("age").expect("key to exist") = age.into();
+            element.geometry.set_x(element.geometry.x() + 1.0);
+        }
+        let actual_output = crate::ser::to_feature_collection_string(&elements).unwrap();
+
+        use std::str::FromStr;
+        let actual_output_json = JsonValue::from_str(&actual_output).unwrap();
+        let expected_output_json = json!({
+            "type": "FeatureCollection",
+            "features": [
+                {
+                  "type": "Feature",
+                  "geometry": {
+                    "type": "Point",
+                    "coordinates": [126.6, 10.1]
+                  },
+                  "properties": {
+                    "name": "Dinagat Islands",
+                    "age": 124
+                  }
+                },
+                {
+                  "type": "Feature",
+                  "geometry": {
+                    "type": "Point",
+                    "coordinates": [3.3, 4.5]
+                  },
+                  "properties": {
+                    "name": "Neverland",
+                    "age": 457
+                  }
+                }
+            ]
+        });
+
+        assert_eq!(actual_output_json, expected_output_json);
+    }
 }
