@@ -9,7 +9,7 @@
 //! }
 //! ```
 //!
-//! Your type *must* have a field called `geometry` and it must be `serialized_with` [`serialize_geometry`](crate::ser::serialize_geometry):
+//! Your type *must* have a field called `geometry` and it must be `serialize_with` [`serialize_geometry`](crate::ser::serialize_geometry):
 //!  ```rust, ignore
 //! #[derive(serde::Serialize)]
 //! struct MyStruct {
@@ -85,22 +85,24 @@
 //!
 //! # Reading *and* Writing GeoJSON
 //!
-//! This module is only concerned with Writing out GeoJSON. If you'd also like to reading GeoJSON,
+//! This module is only concerned with Writing out GeoJSON. If you'd also like to read GeoJSON,
 //! you'll want to combine this with the functionality from the [`crate::de`] module:
 //! ```ignore
 //! #[derive(serde::Serialize, serde::Deserialize)]
 //! struct MyStruct {
-//!     // Serialize as geojson, rather than using the type's default serialization
+//!     // Serialize as GeoJSON, rather than using the type's default serialization
 //!     #[serde(serialize_with = "serialize_geometry", deserialize_with = "deserialize_geometry")]
 //!     geometry: geo_types::Point<f64>,
 //!     ...
 //! }
 //! ```
-use crate::{JsonObject, JsonValue, Result};
+use crate::{Feature, JsonObject, JsonValue, Result};
 
 use serde::{ser::Error, Serialize, Serializer};
 
-use std::io;
+use crate::util::expect_owned_object;
+use std::convert::TryFrom;
+use std::{convert::TryInto, io};
 
 /// Serialize a single data structure to a GeoJSON Feature string.
 ///
@@ -198,6 +200,66 @@ where
     Ok(())
 }
 
+/// Convert a `T` into a [`Feature`].
+///
+/// This is analogous to [`serde_json::to_value`](https://docs.rs/serde_json/latest/serde_json/fn.to_value.html)
+///
+/// Note that if (and only if) `T` has a field named `geometry`, it will be serialized to
+/// `feature.geometry`.
+///
+/// All other fields will be serialized to `feature.properties`.
+///
+/// # Examples
+#[cfg_attr(feature = "geo-types", doc = "```")]
+#[cfg_attr(not(feature = "geo-types"), doc = "```ignore")]
+/// use serde::Serialize;
+/// use geojson::{Feature, Value, Geometry};
+/// use geojson::ser::{to_feature, serialize_geometry};
+///
+/// #[derive(Serialize)]
+/// struct MyStruct {
+///     // Serialize `geometry` as geojson, rather than using the type's default serialization
+///     #[serde(serialize_with = "serialize_geometry")]
+///     geometry: geo_types::Point,
+///     name: String,
+/// }
+///
+/// let my_struct = MyStruct {
+///     geometry: geo_types::Point::new(1.0, 2.0),
+///     name: "My Name".to_string()
+/// };
+///
+/// let feature: Feature = to_feature(my_struct).unwrap();
+/// assert_eq!("My Name", feature.properties.unwrap()["name"]);
+/// assert_eq!(feature.geometry.unwrap(), Geometry::new(Value::Point(vec![1.0, 2.0])));
+/// ```
+///
+/// # Errors
+///
+/// Serialization can fail if `T`'s implementation of `Serialize` decides to
+/// fail, or if `T` contains a map with non-string keys.
+pub fn to_feature<T>(value: T) -> Result<Feature>
+where
+    T: Serialize,
+{
+    let js_value = serde_json::to_value(value)?;
+    let mut js_object = expect_owned_object(js_value)?;
+
+    let geometry = if let Some(geometry_value) = js_object.remove("geometry") {
+        Some(crate::Geometry::try_from(geometry_value)?)
+    } else {
+        None
+    };
+
+    Ok(Feature {
+        bbox: None,
+        geometry,
+        id: None,
+        properties: Some(js_object),
+        foreign_members: None,
+    })
+}
+
 /// Serialize elements as a GeoJSON FeatureCollection into the IO stream.
 ///
 /// Note that `T` must have a column called `geometry`.
@@ -255,13 +317,77 @@ where
 /// ```
 pub fn serialize_geometry<IG, S>(geometry: IG, ser: S) -> std::result::Result<S::Ok, S::Error>
 where
-    IG: std::convert::TryInto<crate::Geometry>,
+    IG: TryInto<crate::Geometry>,
     S: serde::Serializer,
+    <IG as TryInto<crate::Geometry>>::Error: std::fmt::Display,
 {
     geometry
         .try_into()
-        .map_err(|_e| Error::custom("failed to convert geometry to geojson"))
-        .and_then(|geojson_geometry| geojson_geometry.serialize(ser))
+        .map_err(serialize_error_msg::<S>)?
+        .serialize(ser)
+}
+
+/// [`serde::serialize_with`](https://serde.rs/field-attrs.html#serialize_with) helper to serialize an optional type like a
+/// [`geo_types`], as an optional GeoJSON Geometry.
+///
+/// # Examples
+#[cfg_attr(feature = "geo-types", doc = "```")]
+#[cfg_attr(not(feature = "geo-types"), doc = "```ignore")]
+/// use geojson::ser::serialize_optional_geometry;
+/// use serde::Serialize;
+/// use serde_json::{json, to_value};
+///
+/// #[derive(Serialize)]
+/// struct MyStruct {
+///     count: usize,
+///     #[serde(
+///         skip_serializing_if = "Option::is_none",
+///         serialize_with = "serialize_optional_geometry"
+///     )]
+///     geometry: Option<geo_types::Point<f64>>,
+/// }
+///
+/// let my_struct = MyStruct {
+///     count: 0,
+///     geometry: Some(geo_types::Point::new(1.2, 0.5)),
+/// };
+/// let json = json! {{
+///     "count": 0,
+///     "geometry": {
+///         "type": "Point",
+///         "coordinates": [1.2, 0.5]
+///     },
+/// }};
+/// assert_eq!(json, to_value(my_struct).unwrap());
+///
+/// let my_struct = MyStruct {
+///     count: 1,
+///     geometry: None,
+/// };
+/// let json = json! {{
+///     "count": 1,
+/// }};
+/// assert_eq!(json, to_value(my_struct).unwrap());
+/// ```
+pub fn serialize_optional_geometry<'a, IG, S>(
+    geometry: &'a Option<IG>,
+    ser: S,
+) -> std::result::Result<S::Ok, S::Error>
+where
+    &'a IG: std::convert::TryInto<crate::Geometry>,
+    S: serde::Serializer,
+    <&'a IG as TryInto<crate::Geometry>>::Error: std::fmt::Display,
+{
+    geometry
+        .as_ref()
+        .map(TryInto::try_into)
+        .transpose()
+        .map_err(serialize_error_msg::<S>)?
+        .serialize(ser)
+}
+
+fn serialize_error_msg<S: Serializer>(error: impl std::fmt::Display) -> S::Error {
+    Error::custom(format!("failed to convert geometry to GeoJSON: {}", error))
 }
 
 struct Features<'a, T>
@@ -280,7 +406,7 @@ where
     }
 }
 
-impl<'a, T> serde::Serialize for Features<'a, T>
+impl<T> serde::Serialize for Features<'_, T>
 where
     T: Serialize,
 {
@@ -505,6 +631,42 @@ mod tests {
     mod geo_types_tests {
         use super::*;
         use crate::de::tests::feature_collection;
+        use crate::Geometry;
+
+        #[test]
+        fn serializes_optional_point() {
+            #[derive(serde::Serialize)]
+            struct MyStruct {
+                count: usize,
+                #[serde(
+                    skip_serializing_if = "Option::is_none",
+                    serialize_with = "serialize_optional_geometry"
+                )]
+                geometry: Option<geo_types::Point<f64>>,
+            }
+
+            let my_struct = MyStruct {
+                count: 0,
+                geometry: Some(geo_types::Point::new(1.2, 0.5)),
+            };
+            let json = json! {{
+                "count": 0,
+                "geometry": {
+                    "type": "Point",
+                    "coordinates": [1.2, 0.5]
+                },
+            }};
+            assert_eq!(json, serde_json::to_value(my_struct).unwrap());
+
+            let my_struct = MyStruct {
+                count: 1,
+                geometry: None,
+            };
+            let json = json! {{
+                "count": 1,
+            }};
+            assert_eq!(json, serde_json::to_value(my_struct).unwrap());
+        }
 
         #[test]
         fn geometry_field_without_helper() {
@@ -578,6 +740,42 @@ mod tests {
             assert_eq!(actual_output, expected_output);
         }
 
+        #[test]
+        fn test_to_feature() {
+            #[derive(Serialize)]
+            struct MyStruct {
+                #[serde(serialize_with = "serialize_geometry")]
+                geometry: geo_types::Point<f64>,
+                name: String,
+                age: u64,
+            }
+
+            let my_struct = MyStruct {
+                geometry: geo_types::point!(x: 125.6, y: 10.1),
+                name: "Dinagat Islands".to_string(),
+                age: 123,
+            };
+
+            let actual = to_feature(&my_struct).unwrap();
+            let expected = Feature {
+                bbox: None,
+                geometry: Some(Geometry::new(crate::Value::Point(vec![125.6, 10.1]))),
+                id: None,
+                properties: Some(
+                    json!({
+                        "name": "Dinagat Islands",
+                        "age": 123
+                    })
+                    .as_object()
+                    .unwrap()
+                    .clone(),
+                ),
+                foreign_members: None,
+            };
+
+            assert_eq!(actual, expected)
+        }
+
         #[test]
         fn serialize_feature_collection() {
             #[derive(Serialize)]
